@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: statistics
 version: 0.13.2.3
-id: statistics-0.13.2.3-9cfca80e6aade4eaf97a03a2085a3b43
-key: stati_63G6Zey3UJB0HQiuuAibsd
+id: statistics-0.13.2.3-6bd64b4887ba2aab582281d26d4ec1c8
+key: stati_75vGhdU2vngDh8OPx9VyWy
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -63,14 +63,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/statistics-0.13.2.3
-hs-libraries: HSstatistics-0.13.2.3-63G6Zey3UJB0HQiuuAibsd
+hs-libraries: HSstatistics-0.13.2.3-75vGhdU2vngDh8OPx9VyWy
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
-    math-functions-0.1.6.0-ea20ce369bb9f305d4ce2d1a9db5e80e
+    math-functions-0.1.7.0-46faa63fe0537168b78e38dab80faf11
     monad-par-0.3.4.7-71f3c038a9542ac299ca5b790fa5b12a
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
